/** *************************************************************************
 *
 * @file	ppg_data.h
 * @brief	This is PPG data header file for S1C17W23.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2016. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 07/20/2016    1.00
 *				- First revision.
 *
 ************************************************************************* */

#ifndef PPG_DATA_H_
#define PPG_DATA_H_


// Range target:  30 - 240bpm

#define DATA_NUM				200		// 30bpm * 2 = 4sec,  4sec / 20ms = 200

typedef struct ppg_data {

	signed short		rawData[DATA_NUM];				// measured data set
	signed short		firRes[DATA_NUM];				// FIR results
	signed short		ccRes[DATA_NUM];				// cross-correlation result

	unsigned short		dataPtr;						// index pointer for rawData[], firRes[] recording
	unsigned short		availDataNum;					// available data number
	unsigned short		measuredVal;					// measured value
	unsigned short		calcHRIter;						// iteration to calculate heart rate
	unsigned short		numFrame;						// number of frame for cross-correlation
	unsigned short		heartRate;						// heart rate in BPM
	unsigned short		rawMinVal;						// minimum raw value
	unsigned short		rawMaxVal;						// maximum raw value
	unsigned short		rawRange;						// rawMaxVal - rawMinVal
	unsigned short		rawSystoleLevel;				// systole level
	unsigned short		currHeartMark;					// current heart mark
	unsigned short		systoleCycleCounter;			// systole cycle counter
	unsigned short		hRFromSystole;					// calculated heart rate from systole cycle

	volatile unsigned short		running;			// 0: stop  1: running
	volatile unsigned short		interm;				// 0: continuous  1: intermittent
	volatile unsigned short		highGain;			// 0: low gain  1: high gain
	volatile unsigned short		lpf;				// 0: noise filter OFF  1: noise filter ON
	volatile unsigned short		samplingDelay;		// sampling delay coefficient
	volatile unsigned short		stage;				// 0: measuring value  1: measure done
	volatile unsigned short		p1xBase;			// base data for P1X
	volatile unsigned short		overRunTimes;		// 0-1: no problem (1: only 1st call)  else: over run

} PPG_DATA;


#endif /*PPG_DATA_H_*/
