/** *************************************************************************
 *
 * @file	remc_reg.h
 * @brief	Definition of the Ir Remote Controller(REMC) Register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 10/04/2013    1.00
 *				- First revision.
 *
 ************************************************************************* */
#ifndef	REMC_REG_H__
#define	REMC_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// REMC Clock Control Register.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		CLKSRC		: 2;	///< These bits select the clock source of REMC.
		volatile unsigned short		reserved_1	: 2;	///< Reserved.
		volatile unsigned short		CLKDIV		: 4;	///< These bits select the division ratio of the REMC operating clock.
		volatile unsigned short		DBRUN		: 1;	///< This bit sets whether the REMC operating clock is supplied in DEBUG mode or not.
		volatile unsigned short		reserved_2	: 7;	///< Reserved.
	} bit;
} REMCLK_REG;

/// REMC Data Bit Counter Control Register.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		MODEN		: 1;	///< This bit enables the REMC operations.
		volatile unsigned short		REMCRST		: 1;	///< This bit issues software reset to the REMC.
		volatile unsigned short		TRMD		: 1;	///< This bit selects the operation mode of the 16-bit counter for data signal generation.
		volatile unsigned short		BUFEN		: 1;	///< This bit enables or disables the compare buffers.
		volatile unsigned short		REMOINV		: 1;	///< This bit inverts the REMO output signal.
		volatile unsigned short		reserved_1	: 3;	///< Reserved.
		volatile unsigned short		PRUN		: 1;	///< This bit starts/stops counting by the internal counters.
		volatile unsigned short		PRESET		: 1;	///< This bit resets the internal counters.
		volatile unsigned short		reserved_2	: 6;	///< Reserved.
	} bit;
} REMDBCTL_REG;

/// REMC Data Bit Counter.
typedef union {
	volatile unsigned short			reg;
} REMDBCNT_REG;

/// REMC Data Bit Active Pulse Length Register.
typedef union {
	volatile unsigned short			reg;
} REMAPLEN_REG;

/// REMC Data Bit Length Register.
typedef union {
	volatile unsigned short			reg;
} REMDBLEN_REG;

/// REMC Status and Interrupt Flag Register.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		APIF		: 1;	///< This bit indicate the REMC AP interrupt cause occurrence status.
		volatile unsigned short		DBIF		: 1;	///< This bit indicate the REMC DB interrupt cause occurrence status.
		volatile unsigned short		reserved_1	: 6;	///< Reserved.
		volatile unsigned short		APLENBSY	: 1;	///< This bit indicates whether a compare match occurs by the REMAPLEN buffer or not.
		volatile unsigned short		DBLENBSY	: 1;	///< This bit indicates whether a compare match occurs by the REMDBLEN buffer or not.
		volatile unsigned short		DBCNTRUN	: 1;	///< This bit indicates whether the 16-bit counter for data signal generation is running or not. 
		volatile unsigned short		reserved_2	: 5;	///< Reserved.
	} bit;
} REMINTF_REG;

/// REMC Interrupt Enable Register.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		APIE		: 1;	///< This bit enable REMC AP interrupts.
		volatile unsigned short		DBIE		: 1;	///< This bit enable REMC DB interrupts.
		volatile unsigned short		reserved_1	: 14;	///< Reserved.
	} bit;
} REMINTE_REG;

/// REMC Carrier Waveform Register.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		CRPER		: 8;	///< These bits set the carrier signal cycle.
		volatile unsigned short		CRDTY		: 8;	///< These bits set the high level period of the carrier signal.
	} bit;
} REMCARR_REG;

/// REMC Carrier Modulation Control Register.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		CARREN		: 1;	///< This bit enables carrier modulation.
		volatile unsigned short		reserved_1	: 15;	///< Reserved.
	} bit;
} REMCCTL_REG;


#ifdef __cplusplus
}
#endif

#endif	// REMC_REG_H__

