/** *************************************************************************
 *
 * @file	osc.c
 * @brief	This is OSC file for S1C17W22_W23.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 04/25/2014    1.00
 *				- First revision.
 *
 ************************************************************************* */


 #include "init.h"
 #include "osc.h"

/************************************************************************
 *   Stop OSC1
 *   param    :     void
 *   return   :     char OSC_STOP_NG
 *                       OSC_STOP_OK
 ***********************************************************************/
 char stopOsc1(void) {


	 CLGOSC &= 0xfffd;

 	return OSC_STOP_OK;
 }

/************************************************************************
 *   Start OSC1
 *   param    :     void
 *   return   :     none
 ***********************************************************************/
 void startOsc1(void) {

	 CLGOSC |= 0x0002;

 }
/************************************************************************
 *   Stop OSC3
 *   param    :     void
 *   return   :     char OSC_STOP_NG
 *                       OSC_STOP_OK
 ***********************************************************************/
 char stopOsc3(void) {

	 CLGOSC &= 0xfffB;

	return OSC_STOP_OK;
 }

/************************************************************************
 *   Start OSC3
 *   param    :     clk : wait cycles
 *   return   :     none
 ***********************************************************************/
 void startOsc3(unsigned char freq) {

	 PDMODSEL |= 0x18;
	 PDFNCSEL |= 0x280;

	 CLGINTF = 0x0004;			// CLGINTF_OSC3STAIF = 1  clear interrupt flag
	 CLGOSC |= 0x0000;			// CLGOSC_OSC3EN = 0  disable OSC3
	 CLGINTE = 0x0004;		// CLGINTE_OSC3STAIE = 1  enable interrupt
	 // CLGOSC3 |= 0x0e16;		// OSC3 X'tal
	 // CLG_OSC3 |= 0x0d16;		// OSC3 CR
	 CLGOSC3 = (freq << 10);	// OSC3 INT
	 CLGOSC |= 0x0004;			// CLGOSC_OSC3EN = 1  enable OSC3

	 // while(!(CLGINTF & 0x004)){}


 }
/************************************************************************
 *   Stop IOSC
 *   param    :     void
 *   return   :     char OSC_STOP_NG
 *                       OSC_STOP_OK
 ***********************************************************************/
 char stopIOsc(void) {

	 CLGOSC &= 0xfffe;
	return OSC_STOP_OK;
 }

/************************************************************************
 *   Start IOSC
 *   param    :     clk : wait cycles
 *   return   :     none
 ***********************************************************************/
 void startIOsc(unsigned char clk) {

	 CLGOSC |= 0x0001;
 }


/************************************************************************
 *   Change clock OSC -> OSC1
 *   param    :     void
 *   return   :     none
 ***********************************************************************/
 void changeSysClkOscto1(void) {
	unsigned short regVal;
	MSCPROT = 0x96;
	startOsc1();							//OSC1 ON

	regVal = CLGSCLK;
	regVal &= 0xfffc;
	regVal |= 0x0001;
	CLGSCLK = regVal;
	MSCPROT = 0x00;
 }

/************************************************************************
 *   Change clock OSC -> IOSC
 *   param    :     void
 *   return   :     none
 ***********************************************************************/
 void changeSysClkOsctoI(void) {
	unsigned short regVal;
	MSCPROT = 0x96;
	startIOsc(IOSC_WAIT_CYCLE_64);			//IOSC ON

	regVal = CLGSCLK;
	regVal &= 0xfffc;
	CLGSCLK = regVal;
	MSCPROT = 0x00;
 }

/************************************************************************
 *   Change clock OSC -> OSC3
 *   param    :     void
 *   return   :     none
 ***********************************************************************/
 void changeSysClkOscto3(unsigned char freq) {

	unsigned short regVal;
	MSCPROT = 0x96;
	startOsc3(freq);			//OSC3 ON

 	regVal = CLGSCLK;
 	regVal &= 0xfffc;
 	regVal |= 0x0002;
 	CLGSCLK = regVal;
 	MSCPROT = 0x00;

 }
