/*******************************************************************************
 *
 * @file	boot.c
 * @brief	This is vector and interrupt program with C.
 *
 * @par		Copyright:
 * 			Copyright (C) SEIKO EPSON CORPORATION 2015-2015. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 13 Nov, 2015	1.00
 *				- First revision.
 *
 ******************************************************************************/
#include "crt0.h"
#include "init.h"

/* --- function declaration --- */

void _init_device( void);

static void initPwg(void);
static void initItc(void);



/* --- Non-Maskable Interrupts --- */
C17_INTERRUPT_HANDLER(_vector01_handler, intAddrErr);	// Address misaligned

/****************************************************************************
 * _init_device function.
 *
 * @brief	Initialize device module.
 ***************************************************************************/
void _init_device(void)
{
	/// Initialize module.
	initPwg();						/// - Initialize PWG.
	initItc();						/// - Initialize ITC.
	setFlashcAccessCycle( FLASHCWAIT_RDWAIT_1 );

	return;
}

/****************************************************************************
 * initPwg function.
 *
 * @brief	Initialize PWG module.
 ***************************************************************************/
static void initPwg(void)
{

	/// disable write-protec.
	protectMisc( MSCPROT_PROTECT_OFF );

#ifdef	PWG2_ENABLE
	/// PWG2 Mode : Automatic mode.
	PWGCTL_PWGMOD		= 0;
#else
	/// PWG Mode : Automatic mode.
	PWGVD1CTL_REGMODE	= 0;
#endif

	/// enable write-protect.
	protectMisc( MSCPROT_PROTECT_ON );

	return;
}


/****************************************************************************
 * initItc function.
 *
 * @brief	 is initialized ITC module.
 ***************************************************************************/
static void initItc(void)
{
	/// Initialize interrupt level.
	ITCLV0_ILV0		= 0;
	ITCLV0_ILV1		= 0;
	ITCLV1_ILV2		= 0;
	ITCLV1_ILV3		= 0;
	ITCLV2_ILV4		= 0;
	ITCLV2_ILV5		= 0;
	ITCLV3_ILV6		= 0;
	ITCLV3_ILV7		= 0;
	ITCLV4_ILV8		= 0;
	ITCLV4_ILV9		= 0;
	ITCLV5_ILV10	= 0;
	ITCLV5_ILV11	= 0;
	ITCLV6_ILV12	= 0;
	ITCLV6_ILV13	= 0;
	ITCLV7_ILV14	= 0;
	ITCLV7_ILV15	= 0;
	ITCLV8_ILV16	= 0;
	ITCLV8_ILV17	= 0;
	ITCLV9_ILV18	= 0;
	ITCLV9_ILV19	= 0;
	ITCLV10_ILV20	= 0;
	ITCLV10_ILV21	= 0;
	ITCLV11_ILV22	= 0;

	return;
}


/****************************************************************************
 * intAddrErr function.
 *
 * @brief	Interrupt handler for "Address misaligned".
 ***************************************************************************/
void intAddrErr(void)
{
	/// Undecid processing.
	asm("halt");
}


