/** *************************************************************************
 *
 * @file	ppg_mon.h
 * @brief	This is PPG monitor header file for S1C17W23.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2016. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 05/10/2016    1.00
 *				- First revision.
 *
 ************************************************************************* */

#ifndef PPG_MON_H_
#define PPG_MON_H_


#define DATA_NUM					200							// data number

#define FIR_N_MAX					30							// Max. tap number N = 61  -->  ( N - 1 ) / 2 = 30
#define CONTROL_HEADER_LEN			( 14 + 3 * FIR_N_MAX )		// header length of control command

typedef enum { STEP_WAITING_COMMAND, STEP_SKIPPING_FIRST, STEP_MEASURING, STEP_DONE } STEP_EN;


typedef struct ppg_mon {

	signed short		rawData[DATA_NUM];				// raw data
	signed short		firRes[DATA_NUM];				// FIR's result
	signed short		ccRes[DATA_NUM];				// cross-correlation result
	signed short		firCoef[FIR_N_MAX];				// FIR's coefficient

	unsigned char		rcvData[CONTROL_HEADER_LEN];	// receive data
	unsigned char		sndData[6];						// send data = 12bit*2 + 16bit = 2Byte*2 + 2Byte = 6Byte

	volatile unsigned short		interm;				// 0: continuous  1: intermittent
	volatile unsigned short		highGain;			// 0: low gain  1: high gain
	volatile unsigned short		lpf;				// 0: LPF OFF  1: LPF ON
	volatile unsigned short		filter1;			// 0: none  1: FIR filter  2: calculate cross-correlation value
	volatile unsigned short		filter2;			// 0: none  1: FIR filter  2: calculate cross-correlation value
	volatile unsigned short		skipNum;			// skipped first number
	volatile unsigned short		dataSetNum;			// data set number
	volatile unsigned short		scanInterval;		// scan interval coefficient
	volatile unsigned short		samplingDelay;		// sampling delay coefficient
	volatile unsigned short		firNum;				// FIR's N
	volatile unsigned short		numFrame;			// number of frame

	unsigned short		dataPtr;						// data pointer
	unsigned short		measuredVal;					// measured value
	unsigned short		measCount;						// measure point counter
	unsigned short		skipCount;						// skipped first counter
	unsigned short		availDataNum;					// available data number for cross-correlation value
	unsigned short		setNum;							// 4 * numFrame

	volatile unsigned short	step;					// STEP_EN  0: waiting command  1: skipping first  2: measuring  3: done
	volatile unsigned short	stage;					// ADC status  0: measuring value  1: measure done
	volatile unsigned short	p1xBase;				// base data for P1X

} PPG_MON;


#endif /*PPG_MON_H_*/
