/** *************************************************************************
 *
 * @file	opcmp_reg.h
 * @brief	Definition of the Op-Amp/Comparator(OPCMP) Register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 10/04/2013    1.00
 *				- First revision.
 *
 ************************************************************************* */
#ifndef	OPCMP_REG_H__
#define	OPCMP_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// Opeamp/Comparator Mode Register.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		MODEN		: 1;	///< This bit enables the OPCMP operations.
		volatile unsigned short		CMPMOD		: 1;	///< This bit enables the comparator function of all channels.
		volatile unsigned short		reserved_1	: 14;	///< Reserved.
	} bit;
} OPCMPMOD_REG;

/// Opeamp/Comparator Controller 0.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		OPCEN		: 1;	///< This bit enables the OPCMP Ch.0 operational amplifier/comparator operations.
		volatile unsigned short		reserved_1	: 5;	///< Reserved.
		volatile unsigned short		OPOEN		: 1;	///< This bit enables the OPCMP Ch.0 operational amplifier output.
		volatile unsigned short		reserved_2	: 4;	///< Reserved.
		volatile unsigned short		CMPD		: 1;	///< This bit indicates the comparison results output from the OPCMP Ch.0 comparator.
		volatile unsigned short		reserved_3	: 4;	///< Reserved.
	} bit;
} OPCMP0CTL_REG;

/// Opeamp/Comparator Controller 1.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		OPCEN		: 1;	///< This bit enables the OPCMP Ch.1 operational amplifier/comparator operations.
		volatile unsigned short		reserved_1	: 5;	///< Reserved.
		volatile unsigned short		OPOEN		: 1;	///< This bit enables the OPCMP Ch.1 operational amplifier output.
		volatile unsigned short		reserved_2	: 4;	///< Reserved.
		volatile unsigned short		CMPD		: 1;	///< This bit indicates the comparison results output from the OPCMP Ch.1 comparator.
		volatile unsigned short		reserved_3	: 4;	///< Reserved.
	} bit;
} OPCMP1CTL_REG;


#ifdef __cplusplus
}
#endif

#endif	// OPCMP_REG_H__

