/** ****************************************************************************
 *
 * @file	boot.c
 * @brief	This is vector and interrupt program with C.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 04/25/2014    1.00
 *				- First revision.
 *
 **************************************************************************** */

/* #include */
#include <string.h>

/* Prototype */
void boot(void);
void dummy(void)__attribute__ ((interrupt_handler));
void nmi(void)__attribute__ ((interrupt_handler));

void clearBss(void);
void copyLmaToVma(void);


/* extern */
extern int main(void);
extern void emu_copro_process(void)__attribute__ ((interrupt_handler));
extern void intUartCh0(void)__attribute__ ((interrupt_handler));
extern void intT16Ch0(void)__attribute__ ((interrupt_handler));
extern void intAdc12Ch0(void)__attribute__ ((interrupt_handler));

extern unsigned char __START_bss;
extern unsigned char __END_bss;
extern unsigned char __START_data;
extern unsigned char __START_data_lma;
extern unsigned char __END_data;


/* special definitions for vector table  */
typedef void func(void);
#ifdef __POINTER16
#define VECTOR(vec)  (vec),0
#else
#define VECTOR(vec)  (vec)
#endif

/* vector table */
func *const vector[] = {		// No	Base+	Name
	VECTOR(boot),				// 0	00		Reset
	VECTOR(dummy),				// 1	04		Illegal Address Int.
	VECTOR(nmi),				// 2	08		NMI
	VECTOR(emu_copro_process),	// 3	0c		Co-processor emulation
	VECTOR(dummy),				// 4	10		SVD
	VECTOR(dummy),				// 5	14		PORT Int.
	VECTOR(dummy),				// 6	18		PWG2 Int.
	VECTOR(dummy),				// 7	1c		CLG Int.
	VECTOR(dummy),				// 8	20		RTC Int.
	VECTOR(intT16Ch0),			// 9	24		T16 Ch.0 Int.
	VECTOR(intUartCh0),			// 10	28		UART Ch.0 Int.
	VECTOR(dummy),				// 11	2c		T16 Ch.1 Int.
	VECTOR(dummy),				// 12	30		SPI interrupt
	VECTOR(dummy),				// 13	34		I2C interrupt
	VECTOR(dummy),				// 14	38		T16B Ch.0 Int.
	VECTOR(dummy),				// 15	3c		T16B ch.1 Int.
	VECTOR(dummy),				// 16	40		Reserved
	VECTOR(dummy),        		// 17	44		Reserved
	VECTOR(dummy),				// 18	48		Reserved
	VECTOR(dummy),				// 19	4c		Reserved
	VECTOR(dummy),				// 20	50		SNDA Int.
	VECTOR(dummy),				// 21	54		Reserved
	VECTOR(dummy),				// 22	58		LCD24A Int.
	VECTOR(dummy),				// 23	5c		RFC ch.0 Int.
	VECTOR(dummy),				// 24	60		RFC ch.1 Int.
	VECTOR(dummy),				// 25	64		Reserved
	VECTOR(intAdc12Ch0),		// 26	68		ADC12 Ch.0 Int.
	VECTOR(dummy),				// 27	6c		Reserved
	VECTOR(dummy),				// 28	70		Reserved
	VECTOR(dummy),				// 29	74		Reserved
	VECTOR(dummy),				// 30	78		Reserved
	VECTOR(dummy)				// 31	7c		Reserved
};

/*
 * Dummy Interrupt function.
 * This function has only infinite loop.
 *
 * return: void
 * history: 2008/08/11	start
 */
void dummy(void) {
	// infinite loop
	while(1) {
	}
	return ;
}


/*
 * Non Maskable Interrupt function.
 *
 * return: void
 * history: 2008/08/11	start
 */
void nmi(void) {
	// Processing is undecided.
	return ;
}



/*
 * Boot function
*/

void boot(void) {
	asm("xld.a  %sp, 0x1fc0");  	// Set SP in RAM

	clearBss();						// clear the bss area
	copyLmaToVma();					// copy LMA data to VMA data
//	asm("ei");						//interrupt enable

	main();							// Call main
}

/*
 * ClearBss function.
 * This function clears the bss area.
 *
 * return: void
 * history: 2008/08/11	start
 */
void clearBss(void) {
	memset(&__START_bss, 0, (size_t)(&__END_bss - &__START_bss));
}


/*
 * copyLmaToVma function.
 * This function copys LMA data to VMA data.
 *
 * return: void
 * history: 2008/08/11	start
 */
void copyLmaToVma(void) {
	memcpy(&__START_data, &__START_data_lma, (size_t)(&__END_data - &__START_data));
}

