/** *************************************************************************
 *
 * @file	t16_ch1.c
 * @brief	This is 16-bit Ch.1 Timers driver header file for S1C17W22_W23.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 04/25/2014    1.00
 *				- First revision.
 *
 ************************************************************************* */

#include "t16_ch1.h"


#if 0

/** *************************************************************************
 * initT16Ch1 function.
 *
 * @brief	T16 Ch.1 timer initialize.
 *
 * @retval	STATUS_OK	Success.
 * @retval	STATUS_NG	Failed.
 ************************************************************************* */
void initT16Ch1( void )
{
	/// Check OSC1.
//	if ( CLGOSC_OSC1EN == 0 ) {
//		return;
//	}

	/// Stop T16 Ch.1 Timer.
 	stopT16Ch1();

	T16_1CTL_MODEN		= 0;				/// - Stop supplying operating clock

	/// Configure the T16 Ch.1 operating clock.
	T16_1CLK_CLKSRC 	= 0;				/// - Clock source selection(setting IOSC)
	T16_1CLK_CLKDIV 	= 0;				/// - Clock division ratio selection(setting 1/1)
	T16_1CLK_DBRUN		= 0;				/// - No clock supplied in DEBUG mode

	/// Enable count operation clock.
	T16_1CTL_MODEN		= 1;				/// - Start supplying operating clock.

	/// Select operation mode.
	T16_1MOD_TRMD		= 0;				/// - Set Repeat mode.

	/// initialize interrupt.
	T16_1INTF			= 0x0001;			/// - Clear interrupt flag(T16_1INTF_UFIF = 1).
	T16_1INTE_UFIE		= 0;				/// - Disable interrupt.
	ILVT16_1			= INTERRUPT_LEVEL3;	/// - Set interrupt level-3.

	/// Preset reload data to counter.
	presetT16Ch1Count(0xffff);

	return;
}

#endif


/** *************************************************************************
 * startT16Ch1  function.
 *
 * @brief	T16 Ch.1 timer start.
 ************************************************************************* */
void startT16Ch1(void)
{
	/// Clear interrupt flag.
	//T16_1INTF_UFIF		= 1;
	T16_1INTF			= 0x0001;
	/// Enable T16 Ch.1 underflow interrupts.
	T16_1INTE_UFIE		= 1;
	/// T16_1CTL.PRUN set 1(timer start).
	T16_1CTL_PRUN		= 1;
}


/** *************************************************************************
 * stopT16Ch1 function.
 *
 * @brief	T16 Ch.1 timer stop.
 ************************************************************************* */
void stopT16Ch1(void)
{
	/// T16_1CTL.PRUN set 1(timer stop).
	T16_1CTL_PRUN		= 0;
	/// Disble T16 Ch.1 underflow interrupts.
	T16_1INTE_UFIE		= 0;
	/// Clear interrupt flag.
	//T16_1INTF_UFIF		= 1;
	T16_1INTF			= 0x0001;
}


/** *************************************************************************
 * presetT16Ch1Count function.
 *
 * @brief	 Set T16 Ch.1 timer count value.
 *
 * @param	count		Counter Data.
 ************************************************************************* */
void presetT16Ch1Count( unsigned short count )
{
	/// Set the initial value to be preset to the counter.
	T16_1TR = count;

	/// Presets the reload data stored in the T16_1TR register to the counter.
	T16_1CTL_PRESET = 1;

	/// It is confirmed whether the preset finished.
	while ( T16_1CTL_PRESET != 0 ) {
		// wait...
	}
}


/** *************************************************************************
 * getT16Ch1Count function.
 *
 * @brief	 Get T16 Ch.1 timer counter value.
 *
 * @return 	data	Return count value.
 ************************************************************************* */
unsigned short getT16Ch1Count( void )
{
	return ( T16_1TC );
}


#if 0

/** *************************************************************************
 * intT16 function.
 *
 * @brief	First, It checks in underflow interruption.
 * 			Next, underflow interruption flag is cleared.
 *			then, Increment the interrupt counter.
 ************************************************************************* */
void intT16Ch1(void)
{
}

#endif

