/****************************************************************************
 *
 * @file	ad12_reg.h
 * @brief	Definition of the A/D converter(ADC12) Register.
 *
 * @par		Copyright:
 *			Copyright (C) SEIKO EPSON CORPORATION 2013-2014. All rights reserved.
 *
 * @warning -
 *
 * @par		History:
 *			- 10/04/2013    1.00
 *				- First revision.
 *			- 03/27/2014    1.10
 *				- Modify register definition.
 *
 ***************************************************************************/
#ifndef	AD12_REG_H__
#define	AD12_REG_H__

#ifdef	__cplusplus
extern "C" {
#endif


/// A/D Converter Control Register.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		MODEN		: 1;	///< This bit enables the ADC12A operations.
		volatile unsigned short		ADST		: 1;	///< This bit starts A/D conversion or enables to accept triggers.
		volatile unsigned short		reserved_1	: 8;	///< Reserved.
		volatile unsigned short		BSYSTAT		: 1;	///< This bit indicates whether the ADC12A is executing A/D conversion or not.
		volatile unsigned short		reserved_2	: 1;	///< Reserved.
		volatile unsigned short		ADSTAT		: 3;	///< These bits indicate the analog input pin number m being A/D converted.
		volatile unsigned short		reserved_3	: 1;	///< Reserved.
	} bit;
} ADC12_0CTL_REG;

/// A/D Converter Triger/Channel Select Register.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		SMPCLK		: 3;	///< These bits set the analog input signal sampling time.
		volatile unsigned short		reserved_1	: 1;	///< Reserved.
		volatile unsigned short		CNVTRG		: 2;	///< These bits select a trigger source to start A/D conversion.
		volatile unsigned short		CNVMD		: 1;	///< This bit sets the A/D conversion mode.
		volatile unsigned short		STMD		: 1;	///< This bit selects the data alignment when the conversion results are loaded into the A/D conversion result registers.
		volatile unsigned short		STAAIN		: 3;	///< These bits set the analog input pin to be A/D converted first.
		volatile unsigned short		ENDAIN		: 3;	///< These bits set the analog input pin to be A/D converted last.
		volatile unsigned short		reserved_2	: 2;	///< Reserved.
	} bit;
} ADC12_0TRG_REG;

/// A/D Converter Configulation Register.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		VRANGE		: 2;	///< These bits set the A/D converter operating voltage range.
		volatile unsigned short		reserved_1	: 14;	///< Reserved.
	} bit;
} ADC12_0CFG_REG;

/// A/D Converter Interrupt Flag Regisger.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		AD0CIF		: 1;	///< This bit indicate Analog input signal 0 A/D conversion completion interrupt cause occurrence status.
		volatile unsigned short		AD1CIF		: 1;	///< This bit indicate Analog input signal 1 A/D conversion completion interrupt cause occurrence status.
		volatile unsigned short		AD2CIF		: 1;	///< This bit indicate Analog input signal 2 A/D conversion completion interrupt cause occurrence status.
		volatile unsigned short		AD3CIF		: 1;	///< This bit indicate Analog input signal 3 A/D conversion completion interrupt cause occurrence status.
		volatile unsigned short		AD4CIF		: 1;	///< This bit indicate Analog input signal 4 A/D conversion completion interrupt cause occurrence status.
		volatile unsigned short		AD5CIF		: 1;	///< This bit indicate Analog input signal 5 A/D conversion completion interrupt cause occurrence status.
		volatile unsigned short		AD6CIF		: 1;	///< This bit indicate Analog input signal 6 A/D conversion completion interrupt cause occurrence status.
		volatile unsigned short		AD7CIF		: 1;	///< This bit indicate Analog input signal 7 A/D conversion completion interrupt cause occurrence status.
		volatile unsigned short		AD0OVIF		: 1;	///< This bit indicate Analog input signal 0 A/D conversion result overwrite error interrupt cause occurrence status.
		volatile unsigned short		AD1OVIF		: 1;	///< This bit indicate Analog input signal 1 A/D conversion result overwrite error interrupt cause occurrence status.
		volatile unsigned short		AD2OVIF		: 1;	///< This bit indicate Analog input signal 2 A/D conversion result overwrite error interrupt cause occurrence status.
		volatile unsigned short		AD3OVIF		: 1;	///< This bit indicate Analog input signal 3 A/D conversion result overwrite error interrupt cause occurrence status.
		volatile unsigned short		AD4OVIF		: 1;	///< This bit indicate Analog input signal 4 A/D conversion result overwrite error interrupt cause occurrence status.
		volatile unsigned short		AD5OVIF		: 1;	///< This bit indicate Analog input signal 5 A/D conversion result overwrite error interrupt cause occurrence status.
		volatile unsigned short		AD6OVIF		: 1;	///< This bit indicate Analog input signal 6 A/D conversion result overwrite error interrupt cause occurrence status.
		volatile unsigned short		AD7OVIF		: 1;	///< This bit indicate Analog input signal 7 A/D conversion result overwrite error interrupt cause occurrence status.
	} bit;                                                   
} ADC12_0INTF_REG;

/// A/D Converter Interrupt Enable Regisger.
typedef union {
	volatile unsigned short			reg;
	struct {
		volatile unsigned short		AD0CIE		: 1;	///< This bit enable Analog input signal 0 A/D conversion completion interrupt.
		volatile unsigned short		AD1CIE		: 1;	///< This bit enable Analog input signal 1 A/D conversion completion interrupt.
		volatile unsigned short		AD2CIE		: 1;	///< This bit enable Analog input signal 2 A/D conversion completion interrupt.
		volatile unsigned short		AD3CIE		: 1;	///< This bit enable Analog input signal 3 A/D conversion completion interrupt.
		volatile unsigned short		AD4CIE		: 1;	///< This bit enable Analog input signal 4 A/D conversion completion interrupt.
		volatile unsigned short		AD5CIE		: 1;	///< This bit enable Analog input signal 5 A/D conversion completion interrupt.
		volatile unsigned short		AD6CIE		: 1;	///< This bit enable Analog input signal 6 A/D conversion completion interrupt.
		volatile unsigned short		AD7CIE		: 1;	///< This bit enable Analog input signal 7 A/D conversion completion interrupt.
		volatile unsigned short		AD0OVIE		: 1;	///< This bit enable Analog input signal 0 A/D conversion result overwrite error interrupt.
		volatile unsigned short		AD1OVIE		: 1;	///< This bit enable Analog input signal 1 A/D conversion result overwrite error interrupt.
		volatile unsigned short		AD2OVIE		: 1;	///< This bit enable Analog input signal 2 A/D conversion result overwrite error interrupt.
		volatile unsigned short		AD3OVIE		: 1;	///< This bit enable Analog input signal 3 A/D conversion result overwrite error interrupt.
		volatile unsigned short		AD4OVIE		: 1;	///< This bit enable Analog input signal 4 A/D conversion result overwrite error interrupt.
		volatile unsigned short		AD5OVIE		: 1;	///< This bit enable Analog input signal 5 A/D conversion result overwrite error interrupt.
		volatile unsigned short		AD6OVIE		: 1;	///< This bit enable Analog input signal 6 A/D conversion result overwrite error interrupt.
		volatile unsigned short		AD7OVIE		: 1;	///< This bit enable Analog input signal 7 A/D conversion result overwrite error interrupt.
	} bit;                                                   
} ADC12_0INTE_REG;                                             

/// A/D Converter Result Register 0.
typedef union {
	volatile unsigned short			reg;
} ADC12_0AD0D_REG;

/// A/D Converter Result Register 1.
typedef union {
	volatile unsigned short			reg;
} ADC12_0AD1D_REG;

/// A/D Converter Result Register 2.
typedef union {
	volatile unsigned short			reg;
} ADC12_0AD2D_REG;

/// A/D Converter Result Register 3.
typedef union {
	volatile unsigned short			reg;
} ADC12_0AD3D_REG;

/// A/D Converter Result Register 4.
typedef union {
	volatile unsigned short			reg;
} ADC12_0AD4D_REG;

/// A/D Converter Result Register 5.
typedef union {
	volatile unsigned short			reg;
} ADC12_0AD5D_REG;



#ifdef __cplusplus
}
#endif

#endif	// AD12_REG_H__

